==> ulyxex.0.0.6.with-tinyMce.zip: pages/code/admin_links.php <==
<?php
class Links extends Admin {
	function __construct() {
		$this->pagePos = isset($_GET['pg'])?$_GET['pg']:0;
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function user_params($userId) {
		$query = "SELECT * FROM ".USERS." WHERE ID = ".$userId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function totalItems($table) {
		$query = "SELECT COUNT(ID) AS NUM FROM ".$table;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result['NUM'];	
	}
	public function update_links() {
		$values = $_POST;
		foreach($values as $k=>$v) {
			if ( preg_match("/\_/",$k) ) {
				list($key,$id) = explode("_",$k);
				$formValues[$id][$key] = $v;
			}
		}
		foreach($formValues as $id=>$value) {
			$query = 0;
			if ($value['oldlink'] != $value['link']) {
				$query = "UPDATE ".LINKS." SET LINK = '".$value['link']."' WHERE ID = ".$id;
				$query = $this->q($query);
			}
			if (isset($value['delete'])) {
				$query = "DELETE FROM ".LINKS." WHERE ID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".USERLINKS." WHERE LINKID = ".$id;
				$query = $this->q($query);
				// $query = "DELETE FROM ".ARTICLES." WHERE LINKID = ".$id;
				// $query = $this->q($query);
			}
			if (isset($value['hide']) && $value['oldhide'] == 0) {
				$query = "UPDATE ".LINKS." SET HIDE = 1 WHERE ID = ".$id;
				$query = $this->q($query);
			} else if (!isset($value['hide']) && $value['oldhide'] == 1) {
				$query = "UPDATE ".LINKS." SET HIDE = 0 WHERE ID = ".$id;
				$query = $this->q($query);
				// $query = "UPDATE ".ARTICLES." SET HIDE = 0 WHERE LINKID = ".$id;
				// $query = $this->q($query);
			}
		}
		$result = "some values have been modified !";;
		return $result;
	}
	public function list_links($pgPos=0) {
		if ($pgPos) $pgPos = ($pgPos - 1) * ADMINITEMSBYPAGE;
		if (isset($_POST['search'])) {
			$queryLevel1 = 	"SELECT ".LINKS.".*,".USERS.".USERNAME FROM ".LINKS.",".USERS." WHERE ".
							USERS.".ID = ".LINKS.".USERID AND ".
							"MATCH(".LINKS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY ".LINKS.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			
			$queryLevel2 = 	"SELECT ".LINKS.".* FROM ".LINKS.",".USERLINKS." WHERE ".
							USERLINKS.".USERID = ".$_SESSION['userid']." AND ".
							USERLINKS.".LINKID = ".LINKS.".ID AND ".
							"MATCH(".LINKS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY ".LINKS.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		} else {
			$queryLevel1 = 	"SELECT ".LINKS.".*,".USERS.".USERNAME FROM ".LINKS.",".USERS." WHERE ".
							USERS.".ID = ".LINKS.".USERID ORDER BY ".LINKS.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			
			$queryLevel2 = 	"SELECT ".LINKS.".* FROM ".LINKS.",".USERLINKS." WHERE ".
							USERLINKS.".USERID = ".$_SESSION['userid']." AND ".
							USERLINKS.".LINKID = ".LINKS.".ID ".
							"ORDER BY ".LINKS.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		}
		$queryLevel3 = $queryLevel2;
		
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		
		$searchForm = $this->h->p($this->h->input("submit","",$this->tr->w("search name"))." ".$this->h->input("text","search",""));
		$searchForm = $this->h->form($searchForm,"search","post","admin.php?action=links");
		
		$linkListSubmit = $this->h->p($this->h->input("submit","",$this->tr->w("update all")));
		
		$linkList = $this->h->h3($this->tr->w("links list"));
		$linkList .= $this->h->input("hidden","update",1);
		$i = 1;
		while ( $line = mysql_fetch_assoc($query) ) {
			$content = $this->h->input("hidden","id",$line['ID']);
			$content .= $this->h->ahref("admin.php?action=modify_link&amp;link=".$line['ID'],$this->tr->w("modify"))." ";
			$content .= $this->h->ahref("index.php?cat=link".$line['ID'],$this->tr->w("view"),"target=_blank")." ";
			$params =  ($line['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->tr->w("hide").$this->h->input("checkbox","hide_".$line['ID'],"on",$params)." ";
			$content .= $this->h->input("hidden","oldhide_".$line['ID'],$line['HIDE']);
			$content .= $this->tr->ws("name").$this->h->input("text","name".$line['ID'],$line['NAME'],"readonly size=25")." ";
			$content .= $this->tr->ws("link").$this->h->input("text","link_".$line['ID'],$line['LINK'],"size=35")." ";
			$content .= $this->h->input("hidden","oldlink_".$line['ID'],$line['LINK']);
			$content .= $this->tr->ws("delete").$this->h->input("checkbox","delete_".$line['ID'],"on")." ";
			if ($_SESSION['level'] == 1) $content .= $this->tr->w("{by-").$line['USERNAME']."}";
			$linkList .= $this->h->p($content);
		}
		$nextPages = $this->h->p($this->next_pages());
		$linkList = $linkListSubmit.$linkList.$nextPages.$linkListSubmit;
		$result = $searchForm.$this->h->form($linkList,"links","post","admin.php?action=links&amp;pg=".$this->pagePos);
		return $result;
	}
	public function list_links_select($linkId,$name) {
		$query = "SELECT ".LINKS.".ID,".LINKS.".NAME FROM ".LINKS;
		$query = $this->q($query);
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $linkId) {
				$elements[$line['NAME']] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		$result = $this->h->select($elements,$name,$linkId);
		return $result;
	}
	public function next_pages(){
		$queryLevel1 = 	"SELECT COUNT(ID) AS NUM FROM ".LINKS;
		$queryLevel2 = 	"SELECT COUNT(".LINKS.".ID) AS NUM FROM ".LINKS.",".USERS." WHERE ".LINKS.".USERID = ".USERS.".ID AND ".USERS.".USERLEVEL > 1 ";
		$queryLevel3 = 	"SELECT COUNT(ID) AS NUM FROM ".LINKS." WHERE USERID = ".$_SESSION['userid'];
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		$line = mysql_fetch_assoc($query);
		$pagesNumbers = new NextPages($line['NUM'],"action=links");
		$result = $this->h->p($pagesNumbers->numbers());
		return $result;
	}
}
?>

==> ulyxex.0.0.7.with-tinyMce.zip: pages/code/admin_links.php <==
<?php
class Links extends Admin {
	function __construct() {
		$this->pagePos = isset($_GET['pg'])?$_GET['pg']:0;
		$this->h = New Html();
		$this->tr = New Translate();
	}
	public function user_params($userId) {
		$query = "SELECT * FROM ".USERS." WHERE ID = ".$userId;
		$query = $this->q($query);
		$dat = mysql_fetch_assoc($query);
		return $dat;
	}
	public function totalItems($table) {
		$query = "SELECT COUNT(ID) AS NUM FROM ".$table;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result['NUM'];	
	}
	public function update_links() {
		$values = $_POST;
		foreach($values as $k=>$v) {
			if ( preg_match("/\_/",$k) ) {
				list($key,$id) = explode("_",$k);
				$formValues[$id][$key] = $v;
			}
		}
		foreach($formValues as $id=>$value) {
			$query = 0;
			if ($value['oldlink'] != $value['link']) {
				$query = "UPDATE ".LINKS." SET LINK = '".$value['link']."' WHERE ID = ".$id;
				$query = $this->q($query);
			}
			if (isset($value['delete'])) {
				$query = "DELETE FROM ".LINKS." WHERE ID = ".$id;
				$query = $this->q($query);
				$query = "DELETE FROM ".USERLINKS." WHERE LINKID = ".$id;
				$query = $this->q($query);
				// $query = "DELETE FROM ".ARTICLES." WHERE LINKID = ".$id;
				// $query = $this->q($query);
			}
			if (isset($value['hide']) && $value['oldhide'] == 0) {
				$query = "UPDATE ".LINKS." SET HIDE = 1 WHERE ID = ".$id;
				$query = $this->q($query);
			} else if (!isset($value['hide']) && $value['oldhide'] == 1) {
				$query = "UPDATE ".LINKS." SET HIDE = 0 WHERE ID = ".$id;
				$query = $this->q($query);
				// $query = "UPDATE ".ARTICLES." SET HIDE = 0 WHERE LINKID = ".$id;
				// $query = $this->q($query);
			}
		}
		$result = "some values have been modified !";;
		return $result;
	}
	public function list_links($pgPos=0) {
		if ($pgPos) $pgPos = ($pgPos - 1) * ADMINITEMSBYPAGE;
        if (isset($_GET['ownerFilter'])){
            $_SESSION['admin_links_filter'] = $_GET['ownerFilter'];
        }
        if (isset($_POST['reset'])){
            $_SESSION['admin_links_filter'] = "";
        }
        $owners = array();
		$query = $this->q("SELECT ID,USERNAME FROM ".USERS);
		while ( $line = @mysql_fetch_assoc($query) ) {
			$owners[$line['USERNAME']] = $line['ID'];
		}
		if (isset($_POST['search'])) {
			$queryLevel1 = 	"SELECT ".LINKS.".*,".USERS.".USERNAME FROM ".LINKS.",".USERS." WHERE ".
							USERS.".ID = ".LINKS.".USERID AND ".
							"MATCH(".LINKS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY ".LINKS.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			
			$queryLevel2 = 	"SELECT ".LINKS.".* FROM ".LINKS.",".USERLINKS." WHERE ".
							USERLINKS.".USERID = ".$_SESSION['userid']." AND ".
							USERLINKS.".LINKID = ".LINKS.".ID AND ".
							"MATCH(".LINKS.".NAME) AGAINST('".$this->h->safe($_POST['search'])."') ".
							"ORDER BY ".LINKS.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		} elseif (isset($_SESSION['admin_links_filter']) && $_SESSION['admin_links_filter'] != "") {
			$queryLevel1 = 	"SELECT ".LINKS.".*,".USERS.".USERNAME FROM ".LINKS.",".USERS." WHERE ".
                            LINKS.".USERID = ".$_SESSION['admin_links_filter']." AND ".
							USERS.".ID = ".LINKS.".USERID ORDER BY ".LINKS.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			
			$queryLevel2 = 	"SELECT ".LINKS.".* FROM ".LINKS.",".USERLINKS." WHERE ".
							USERLINKS.".USERID = ".$_SESSION['userid']." AND ".
							USERLINKS.".LINKID = ".LINKS.".ID ".
							"ORDER BY ".LINKS.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
		} else {
            $queryLevel1 = 	"SELECT ".LINKS.".*,".USERS.".USERNAME FROM ".LINKS.",".USERS." WHERE ".
							USERS.".ID = ".LINKS.".USERID ORDER BY ".LINKS.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
			
			$queryLevel2 = 	"SELECT ".LINKS.".* FROM ".LINKS.",".USERLINKS." WHERE ".
							USERLINKS.".USERID = ".$_SESSION['userid']." AND ".
							USERLINKS.".LINKID = ".LINKS.".ID ".
							"ORDER BY ".LINKS.".NAME LIMIT ".$pgPos.",".ADMINITEMSBYPAGE;
        }
		$queryLevel3 = $queryLevel2;
		
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		
		$searchForm = $this->h->p($this->h->input("submit","",$this->tr->w("search name"))." ".$this->h->input("text","search",""));
		$searchForm = $this->h->form($searchForm,"search","post","admin.php?action=links");
        
        $resetForm = $this->h->p($this->h->input("submit","",$this->tr->w("no filters")).$this->h->input("hidden","reset",1));
		$resetForm = $this->h->form($resetForm,"reset","post","admin.php?action=links");
		
		$linkListSubmit = $this->h->p($this->h->input("submit","",$this->tr->w("update all")));
		
		$linkList = $this->h->h3($this->tr->w("links list"));
		$linkList .= $this->h->input("hidden","update",1);
		$i = 1;
		while ( $line = mysql_fetch_assoc($query) ) {
			$content = $this->h->input("hidden","id",$line['ID']);
			$content .= $this->h->ahref("admin.php?action=modify_link&amp;link=".$line['ID'],$this->tr->w("modify"))." ";
			$content .= $this->h->ahref("index.php?cat=link".$line['ID'],$this->tr->w("view"),"target=_blank")." ";
			$params =  ($line['HIDE'])?" checked=\"checked\"":null;
			$content .= $this->tr->w("hide").$this->h->input("checkbox","hide_".$line['ID'],"on",$params)." ";
			$content .= $this->h->input("hidden","oldhide_".$line['ID'],$line['HIDE']);
			$content .= $this->tr->ws("name").$this->h->input("text","name".$line['ID'],$line['NAME'],"readonly size=25")." ";
			$content .= $this->tr->ws("link").$this->h->input("text","link_".$line['ID'],$line['LINK'],"size=35")." ";
			$content .= $this->h->input("hidden","oldlink_".$line['ID'],$line['LINK']);
			$content .= $this->tr->ws("delete").$this->h->input("checkbox","delete_".$line['ID'],"on")." ";
			if ($_SESSION['level'] == 1) $content .=  $this->tr->w("by-").$this->h->ahref("admin.php?action=links&amp;ownerFilter=".$owners[$line['USERNAME']],$line['USERNAME']);
			$linkList .= $this->h->p($content);
		}
		$nextPages = $this->h->p($this->next_pages());
		$linkList = $linkListSubmit.$linkList.$nextPages.$linkListSubmit;
		$result = $searchForm.$resetForm.$this->h->form($linkList,"links","post","admin.php?action=links&amp;pg=".$this->pagePos);
		return $result;
	}
	public function list_links_select($linkId,$name) {
		$query = "SELECT ".LINKS.".ID,".LINKS.".NAME FROM ".LINKS;
		$query = $this->q($query);
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $linkId) {
				$elements[$line['NAME']] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		$result = $this->h->select($elements,$name,$linkId);
		return $result;
	}
	public function next_pages(){
		$queryLevel1 = 	"SELECT COUNT(ID) AS NUM FROM ".LINKS;
		$queryLevel2 = 	"SELECT COUNT(".LINKS.".ID) AS NUM FROM ".LINKS.",".USERS." WHERE ".LINKS.".USERID = ".USERS.".ID AND ".USERS.".USERLEVEL > 1 ";
		$queryLevel3 = 	"SELECT COUNT(ID) AS NUM FROM ".LINKS." WHERE USERID = ".$_SESSION['userid'];
		$queries = array("",$queryLevel1,$queryLevel2,$queryLevel3);
		$query = $this->q($queries[$_SESSION['level']]);
		$line = mysql_fetch_assoc($query);
		$pagesNumbers = new NextPages($line['NUM'],"action=links");
		$result = $this->h->p($pagesNumbers->numbers());
		return $result;
	}
}
?>
